<?php
/**
 * Factory Lite Theme Customizer
 *
 * @package Factory Lite
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function factory_lite_custom_controls() {
	load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'factory_lite_custom_controls' );

function factory_lite_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . '/inc/icon-picker.php' );

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.logo .site-title a',
	 	'render_callback' => 'factory_lite_Customize_partial_blogname',
	));

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => 'p.site-description',
		'render_callback' => 'factory_lite_Customize_partial_blogdescription',
	));

	//add home page setting pannel
	$factory_lite_parent_panel = new factory_lite_WP_Customize_Panel( $wp_customize, 'factory_lite_panel_id', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__( 'Homepage Settings', 'factory-lite' ),
		'priority' => 10,
	));

	// Header
	$wp_customize->add_section( 'factory_lite_header' , array(
    	'title' => esc_html__( 'Header', 'factory-lite' ),
		'panel' => 'factory_lite_panel_id'
	) );

   	// Header Background color
	$wp_customize->add_setting('factory_lite_header_background_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'factory_lite_header_background_color', array(
		'label'    => __('Header Background Color', 'factory-lite'),
		'section'  => 'factory_lite_header',
	)));

	$wp_customize->add_setting('factory_lite_header_img_position',array(
	  'default' => 'center top',
	  'transport' => 'refresh',
	  'sanitize_callback' => 'factory_lite_sanitize_choices'
	));
	$wp_customize->add_control('factory_lite_header_img_position',array(
		'type' => 'select',
		'label' => __('Header Image Position','factory-lite'),
		'section' => 'factory_lite_header',
		'choices' 	=> array(
			'left top' 		=> esc_html__( 'Top Left', 'factory-lite' ),
			'center top'   => esc_html__( 'Top', 'factory-lite' ),
			'right top'   => esc_html__( 'Top Right', 'factory-lite' ),
			'left center'   => esc_html__( 'Left', 'factory-lite' ),
			'center center'   => esc_html__( 'Center', 'factory-lite' ),
			'right center'   => esc_html__( 'Right', 'factory-lite' ),
			'left bottom'   => esc_html__( 'Bottom Left', 'factory-lite' ),
			'center bottom'   => esc_html__( 'Bottom', 'factory-lite' ),
			'right bottom'   => esc_html__( 'Bottom Right', 'factory-lite' ),
		), 
	));

	$wp_customize->add_setting('factory_lite_location',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_location',array(
		'label'	=> esc_html__('Add Location','factory-lite'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Brooklyn Street, London', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_header',
		'type'=> 'text'
	));

	$wp_customize->add_setting('factory_lite_location_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_location_text',array(
		'label'	=> esc_html__('Add Location Text','factory-lite'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Visit us', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_header',
		'type'=> 'text'
	));

  	$wp_customize->add_setting('factory_lite_location_icon',array(
		'default'	=> 'fas fa-map-marker-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new factory_lite_Toggle_Fontawesome_Icon_Chooser(
        $wp_customize,'factory_lite_location_icon',array(
		'label'	=> __('Add Location Icon','factory-lite'),
		'transport' => 'refresh',
		'section'	=> 'factory_lite_header',
		'setting'	=> 'factory_lite_location_icon',
		'type'		=> 'icon'
	)));


	$wp_customize->add_setting('factory_lite_phone_number',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_phone_number',array(
		'label'	=> esc_html__('Add Phone Number','factory-lite'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '9876543210', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_header',
		'type'=> 'text'
	));

	$wp_customize->add_setting('factory_lite_phone_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_phone_text',array(
		'label'	=> esc_html__('Add Phone Text','factory-lite'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Phone Line', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_header',
		'type'=> 'text'
	));

    $wp_customize->add_setting('factory_lite_phone_icon',array(
		'default'	=> 'fas fa-phone',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new factory_lite_Toggle_Fontawesome_Icon_Chooser(
        $wp_customize,'factory_lite_phone_icon',array(
		'label'	=> __('Add Phone Icon','factory-lite'),
		'transport' => 'refresh',
		'section'	=> 'factory_lite_header',
		'setting'	=> 'factory_lite_phone_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('factory_lite_email_address',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_email'
	));
	$wp_customize->add_control('factory_lite_email_address',array(
		'label'	=> esc_html__('Add Email Address','factory-lite'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'info@factory.com', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_header',
		'type'=> 'text'
	));

	$wp_customize->add_setting('factory_lite_email_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_email_text',array(
		'label'	=> esc_html__('Add Email Text','factory-lite'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Email address', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_header',
		'type'=> 'text'
	));

    $wp_customize->add_setting('factory_lite_email_icon',array(
		'default'	=> 'fas fa-at',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new factory_lite_Toggle_Fontawesome_Icon_Chooser(
        $wp_customize,'factory_lite_email_icon',array(
		'label'	=> __('Add Email Icon','factory-lite'),
		'transport' => 'refresh',
		'section'	=> 'factory_lite_header',
		'setting'	=> 'factory_lite_email_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('factory_lite_get_quote_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_get_quote_text',array(
		'label'	=> esc_html__('Button Text','factory-lite'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'GET A QUOTE', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_header',
		'type'=> 'text'
	));

	$wp_customize->add_setting('factory_lite_get_quote_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('factory_lite_get_quote_link',array(
		'label'	=> esc_html__('Button Link','factory-lite'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'https://www.example.com/#', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_header',
		'type'=> 'url'
	));

    $wp_customize->add_setting('factory_lite_button_icon',array(
		'default'	=> 'fas fa-long-arrow-alt-right',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new factory_lite_Toggle_Fontawesome_Icon_Chooser(
        $wp_customize,'factory_lite_button_icon',array(
		'label'	=> __('Add Button Icon','factory-lite'),
		'transport' => 'refresh',
		'section'	=> 'factory_lite_header',
		'setting'	=> 'factory_lite_button_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'factory_lite_header_search',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'factory_lite_switch_sanitization'
    ));
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_header_search',array(
      	'label' => esc_html__( 'Show / Hide Search','factory-lite' ),
      	'section' => 'factory_lite_header'
    )));

    $wp_customize->add_setting('factory_lite_search_icon',array(
		'default'	=> 'fas fa-search',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new factory_lite_Toggle_Fontawesome_Icon_Chooser(
        $wp_customize,'factory_lite_search_icon',array(
		'label'	=> __('Add Search Icon','factory-lite'),
		'transport' => 'refresh',
		'section'	=> 'factory_lite_header',
		'setting'	=> 'factory_lite_search_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('factory_lite_search_close_icon',array(
		'default'	=> 'fa fa-window-close',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new factory_lite_Toggle_Fontawesome_Icon_Chooser(
        $wp_customize,'factory_lite_search_close_icon',array(
		'label'	=> __('Add Search Close Icon','factory-lite'),
		'transport' => 'refresh',
		'section'	=> 'factory_lite_header',
		'setting'	=> 'factory_lite_search_close_icon',
		'type'		=> 'icon'
	)));

	//Menus Settings
	$wp_customize->add_section( 'factory_lite_menu_section' , array(
    	'title' => __( 'Menus Settings', 'factory-lite' ),
		'panel' => 'factory_lite_panel_id'
	) );

	$wp_customize->add_setting('factory_lite_navigation_menu_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_navigation_menu_font_size',array(
		'label'	=> __('Menus Font Size','factory-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','factory-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_menu_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('factory_lite_navigation_menu_font_weight',array(
        'default' => 800,
        'transport' => 'refresh',
        'sanitize_callback' => 'factory_lite_sanitize_choices'
	));
	$wp_customize->add_control('factory_lite_navigation_menu_font_weight',array(
        'type' => 'select',
        'label' => __('Menus Font Weight','factory-lite'),
        'section' => 'factory_lite_menu_section',
        'choices' => array(
        	'100' => __('100','factory-lite'),
            '200' => __('200','factory-lite'),
            '300' => __('300','factory-lite'),
            '400' => __('400','factory-lite'),
            '500' => __('500','factory-lite'),
            '600' => __('600','factory-lite'),
            '700' => __('700','factory-lite'),
            '800' => __('800','factory-lite'),
            '900' => __('900','factory-lite'),
        ),
	) );

	// text trasform
	$wp_customize->add_setting('factory_lite_menu_text_transform',array(
		'default'=> 'Uppercase',
		'sanitize_callback'	=> 'factory_lite_sanitize_choices'
	));
	$wp_customize->add_control('factory_lite_menu_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Menus Text Transform','factory-lite'),
		'choices' => array(
            'Uppercase' => __('Uppercase','factory-lite'),
            'Capitalize' => __('Capitalize','factory-lite'),
            'Lowercase' => __('Lowercase','factory-lite'),
        ),
		'section'=> 'factory_lite_menu_section',
	));

	$wp_customize->add_setting('factory_lite_menus_item_style',array(
        'default' => '',
        'transport' => 'refresh',
        'sanitize_callback' => 'factory_lite_sanitize_choices'
	));
	$wp_customize->add_control('factory_lite_menus_item_style',array(
        'type' => 'select',
        'section' => 'factory_lite_menu_section',
		'label' => __('Menu Item Hover Style','factory-lite'),
		'choices' => array(
            'None' => __('None','factory-lite'),
            'Zoom In' => __('Zoom In','factory-lite'),
        ),
	) );

	$wp_customize->add_setting('factory_lite_header_menus_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'factory_lite_header_menus_color', array(
		'label'    => __('Menus Color', 'factory-lite'),
		'section'  => 'factory_lite_menu_section',
	)));

	$wp_customize->add_setting('factory_lite_header_menus_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'factory_lite_header_menus_hover_color', array(
		'label'    => __('Menus Hover Color', 'factory-lite'),
		'section'  => 'factory_lite_menu_section',
	)));

	$wp_customize->add_setting('factory_lite_header_submenus_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'factory_lite_header_submenus_color', array(
		'label'    => __('Sub Menus Color', 'factory-lite'),
		'section'  => 'factory_lite_menu_section',
	)));

	$wp_customize->add_setting('factory_lite_header_submenus_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'factory_lite_header_submenus_hover_color', array(
		'label'    => __('Sub Menus Hover Color', 'factory-lite'),
		'section'  => 'factory_lite_menu_section',
	)));

	//Social links
	$wp_customize->add_section(
		'factory_lite_social_links', array(
			'title'		=>	__('Social Links', 'factory-lite'),
			'priority'	=>	null,
			'panel'		=>	'factory_lite_panel_id'
	));

	$wp_customize->add_setting('factory_lite_social_icons',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_social_icons',array(
		'label' =>  __('Steps to setup social icons','factory-lite'),
		'description' => __('<p>1. Go to Dashboard >> Appearance >> Widgets</p>
			<p>2. Add Vw Social Icon Widget in Topbar Social Links.</p>
			<p>3. Add social icons url and save.</p>','factory-lite'),
		'section'=> 'factory_lite_social_links',
		'type'=> 'hidden'
	));
	$wp_customize->add_setting('factory_lite_social_icon_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_social_icon_btn',array(
		'description' => "<a target='_blank' href='". admin_url('widgets.php') ." '>Setup Social Icons</a>",
		'section'=> 'factory_lite_social_links',
		'type'=> 'hidden'
	));

	//Slider
	$wp_customize->add_section( 'factory_lite_slidersettings' , array(
    	'title' => esc_html__( 'Slider Settings', 'factory-lite' ),
    	'description' => __('Free theme has 3 slides options, For unlimited slides and more options <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/factory-wordpress-theme/">GET PRO</a>','factory-lite'),
		'panel' => 'factory_lite_panel_id'
	) );

    //Selective Refresh
    $wp_customize->selective_refresh->add_partial('factory_lite_slider_arrows',array(
		'selector'        => '#slider .carousel-caption h1',
		'render_callback' => 'factory_lite_Customize_partial_factory_lite_slider_arrows',
	));

	$wp_customize->add_setting( 'factory_lite_slider_arrows',array(
    	'default' => 0,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'factory_lite_switch_sanitization'
    ));
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_slider_arrows',array(
      	'label' => esc_html__( 'Show / Hide Slider','factory-lite' ),
      	'section' => 'factory_lite_slidersettings'
    )));

    $wp_customize->add_setting('factory_lite_slider_type',array(
        'default' => 'Default slider',
        'sanitize_callback' => 'factory_lite_sanitize_choices'
	) );
	$wp_customize->add_control('factory_lite_slider_type', array(
        'type' => 'select',
        'label' => __('Slider Type','factory-lite'),
        'section' => 'factory_lite_slidersettings',
        'choices' => array(
            'Default slider' => __('Default slider','factory-lite'),
            'Advance slider' => __('Advance slider','factory-lite'),
        ),
	));

	$wp_customize->add_setting('factory_lite_advance_slider_shortcode',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_advance_slider_shortcode',array(
		'label'	=> __('Add Slider Shortcode','factory-lite'),
		'section'=> 'factory_lite_slidersettings',
		'type'=> 'text',
		'active_callback' => 'factory_lite_advance_slider'
	));

	for ( $count = 1; $count <= 3; $count++ ) {
		$wp_customize->add_setting( 'factory_lite_slider_page' . $count, array(
			'default'  => '',
			'sanitize_callback' => 'factory_lite_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'factory_lite_slider_page' . $count, array(
			'label'    => esc_html__( 'Select Slider Page', 'factory-lite' ),
			'description' => esc_html__('Slider image size (1600 x 650)','factory-lite'),
			'section'  => 'factory_lite_slidersettings',
			'type'     => 'dropdown-pages',
			'active_callback' => 'factory_lite_default_slider'
		) );
	}

	$wp_customize->add_setting('factory_lite_slider_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_slider_title',array(
		'label'	=> __('Add Text','factory-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Welcome to the Factory', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_slidersettings',
		'type'=> 'text',
		'active_callback' => 'factory_lite_default_slider'
	));

	//content layout
	$wp_customize->add_setting('factory_lite_slider_content_option',array(
        'default' => 'Left',
        'sanitize_callback' => 'factory_lite_sanitize_choices'
	));
	$wp_customize->add_control(new factory_lite_Image_Radio_Control($wp_customize, 'factory_lite_slider_content_option', array(
        'type' => 'select',
        'label' => esc_html__('Slider Content Layouts','factory-lite'),
        'section' => 'factory_lite_slidersettings',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/slider-content1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/slider-content2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/slider-content3.png',
    ),'active_callback' => 'factory_lite_default_slider'
    )));

    //Slider content padding
    $wp_customize->add_setting('factory_lite_slider_content_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_slider_content_padding_top_bottom',array(
		'label'	=> __('Slider Content Padding Top Bottom','factory-lite'),
		'description'	=> __('Enter a value in %. Example:20%','factory-lite'),
		'input_attrs' => array(
            'placeholder' => __( '50%', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_slidersettings',
		'type'=> 'text',
		'active_callback' => 'factory_lite_default_slider'
	));

	$wp_customize->add_setting('factory_lite_slider_content_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_slider_content_padding_left_right',array(
		'label'	=> __('Slider Content Padding Left Right','factory-lite'),
		'description'	=> __('Enter a value in %. Example:20%','factory-lite'),
		'input_attrs' => array(
            'placeholder' => __( '50%', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_slidersettings',
		'type'=> 'text',
		'active_callback' => 'factory_lite_default_slider'
	));

    $wp_customize->add_setting( 'factory_lite_slider_excerpt_number', array(
		'default'              => 45,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'factory_lite_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'factory_lite_slider_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','factory-lite' ),
		'section'     => 'factory_lite_slidersettings',
		'type'        => 'range',
		'settings'    => 'factory_lite_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),'active_callback' => 'factory_lite_default_slider'
	) );

	$wp_customize->add_setting('factory_lite_slider_button_text',array(
		'default'=> esc_html__('GET A QUOTE','factory-lite'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_slider_button_text',array(
		'label'	=> esc_html__('Add Button Text','factory-lite'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'GET A QUOTE', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_slidersettings',
		'type'=> 'text',
		'active_callback' => 'factory_lite_default_slider'
	));

	$wp_customize->add_setting('factory_lite_top_button_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('factory_lite_top_button_url',array(
		'label'	=> __('Add Button URL','factory-lite'),
		'section'	=> 'factory_lite_slidersettings',
		'setting'	=> 'factory_lite_top_button_url',
		'type'	=> 'url',
		'active_callback' => 'factory_lite_default_slider'
	));

	//Slider height
	$wp_customize->add_setting('factory_lite_slider_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_slider_height',array(
		'label'	=> __('Slider Height','factory-lite'),
		'description'	=> __('Specify the slider height (px).','factory-lite'),
		'input_attrs' => array(
            'placeholder' => __( '500px', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_slidersettings',
		'type'=> 'text',
		'active_callback' => 'factory_lite_default_slider'
	));

	//Opacity
	$wp_customize->add_setting('factory_lite_slider_opacity_color',array(
      'default'              => 0.7,
      'sanitize_callback' => 'factory_lite_sanitize_choices'
	));

	$wp_customize->add_control( 'factory_lite_slider_opacity_color', array(
	'label'       => esc_html__( 'Slider Image Opacity','factory-lite' ),
	'section'     => 'factory_lite_slidersettings',
	'type'        => 'select',
	'settings'    => 'factory_lite_slider_opacity_color',
	'choices' => array(
      '0' =>  esc_attr('0','factory-lite'),
      '0.1' =>  esc_attr('0.1','factory-lite'),
      '0.2' =>  esc_attr('0.2','factory-lite'),
      '0.3' =>  esc_attr('0.3','factory-lite'),
      '0.4' =>  esc_attr('0.4','factory-lite'),
      '0.5' =>  esc_attr('0.5','factory-lite'),
      '0.6' =>  esc_attr('0.6','factory-lite'),
      '0.7' =>  esc_attr('0.7','factory-lite'),
      '0.8' =>  esc_attr('0.8','factory-lite'),
      '0.9' =>  esc_attr('0.9','factory-lite')
	),'active_callback' => 'factory_lite_default_slider'
	));

	$wp_customize->add_setting( 'factory_lite_slider_image_overlay',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'factory_lite_switch_sanitization'
   ));
   $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_slider_image_overlay',array(
      	'label' => esc_html__( 'Show / Hide Slider Image Overlay','factory-lite' ),
      	'section' => 'factory_lite_slidersettings',
      	'active_callback' => 'factory_lite_default_slider'
   )));

   $wp_customize->add_setting('factory_lite_slider_image_overlay_color', array(
		'default'           => '#202028',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'factory_lite_slider_image_overlay_color', array(
		'label'    => __('Slider Image Overlay Color', 'factory-lite'),
		'section'  => 'factory_lite_slidersettings',
		'active_callback' => 'factory_lite_default_slider'
	)));


	//Services
	$wp_customize->add_section('factory_lite_services',array(
		'title'	=> __('Our Services Section','factory-lite'),
		'description' => __('For more options of service section <br/><a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/factory-wordpress-theme/">GET PRO</a>','factory-lite'),
		'panel' => 'factory_lite_panel_id',
	));

	$wp_customize->add_setting('factory_lite_services_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_services_text',array(
		'label'	=> esc_html__('Services Heading Text','factory-lite'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Our Services', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_services',
		'type'=> 'text'
	));

	$wp_customize->add_setting('factory_lite_services_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_services_title',array(
		'label'	=> esc_html__('Services Heading Title','factory-lite'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Industries Served', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_services',
		'type'=> 'text'
	));

	$categories = get_categories();
		$cat_posts = array();
			$i = 0;
			$cat_posts[]='Select';
		foreach($categories as $category){
			if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_posts[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('factory_lite_services_category',array(
		'default'	=> 'select',
		'sanitize_callback' => 'factory_lite_sanitize_choices',
	));
	$wp_customize->add_control('factory_lite_services_category',array(
		'type'    => 'select',
		'choices' => $cat_posts,
		'label' => __('Select Category to display services','factory-lite'),
		'section' => 'factory_lite_services',
	));

	//content layout
	$wp_customize->add_setting('factory_lite_services_content_option',array(
        'default' => 'Left',
        'sanitize_callback' => 'factory_lite_sanitize_choices'
	));
	$wp_customize->add_control(new factory_lite_Image_Radio_Control($wp_customize, 'factory_lite_services_content_option', array(
        'type' => 'select',
        'label' => esc_html__('Services Content Layouts','factory-lite'),
        'section' => 'factory_lite_services',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/slider-content1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/slider-content2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/slider-content3.png',
    ))));

    $wp_customize->add_setting( 'factory_lite_services_excerpt_number', array(
		'default'              => 10,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'factory_lite_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'factory_lite_services_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','factory-lite' ),
		'section'     => 'factory_lite_services',
		'type'        => 'range',
		'settings'    => 'factory_lite_services_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 30,
		),
	) );

	//About Us Section
	$wp_customize->add_section('factory_lite_about', array(
		'title'       => __('About Us Section', 'factory-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','factory-lite'),
		'priority'    => null,
		'panel'       => 'factory_lite_panel_id',
	));

	$wp_customize->add_setting('factory_lite_about_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_about_text',array(
		'description' => __('<p>1. More options for about us section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for about us section.</p>','factory-lite'),
		'section'=> 'factory_lite_about',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('factory_lite_about_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_about_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=factory_lite_guide') ." '>More Info</a>",
		'section'=> 'factory_lite_about',
		'type'=> 'hidden'
	));

	//Project Section
	$wp_customize->add_section('factory_lite_project', array(
		'title'       => __('Project Section', 'factory-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','factory-lite'),
		'priority'    => null,
		'panel'       => 'factory_lite_panel_id',
	));

	$wp_customize->add_setting('factory_lite_project_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_project_text',array(
		'description' => __('<p>1. More options for project section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for project section.</p>','factory-lite'),
		'section'=> 'factory_lite_project',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('factory_lite_project_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_project_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=factory_lite_guide') ." '>More Info</a>",
		'section'=> 'factory_lite_project',
		'type'=> 'hidden'
	));

	//Why Choose Us Section
	$wp_customize->add_section('factory_lite_why_choose_us', array(
		'title'       => __('Why Choose Us Section', 'factory-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','factory-lite'),
		'priority'    => null,
		'panel'       => 'factory_lite_panel_id',
	));

	$wp_customize->add_setting('factory_lite_why_choose_us_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_why_choose_us_text',array(
		'description' => __('<p>1. More options for why choose us section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for why choose us section.</p>','factory-lite'),
		'section'=> 'factory_lite_why_choose_us',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('factory_lite_why_choose_us_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_why_choose_us_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=factory_lite_guide') ." '>More Info</a>",
		'section'=> 'factory_lite_why_choose_us',
		'type'=> 'hidden'
	));

	//Teams Section
	$wp_customize->add_section('factory_lite_teams', array(
		'title'       => __('Teams Section', 'factory-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','factory-lite'),
		'priority'    => null,
		'panel'       => 'factory_lite_panel_id',
	));

	$wp_customize->add_setting('factory_lite_teams_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_teams_text',array(
		'description' => __('<p>1. More options for teams section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for teams section.</p>','factory-lite'),
		'section'=> 'factory_lite_teams',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('factory_lite_teams_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_teams_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=factory_lite_guide') ." '>More Info</a>",
		'section'=> 'factory_lite_teams',
		'type'=> 'hidden'
	));

	//Home Page Contact Section
	$wp_customize->add_section('factory_lite_home_page_contact', array(
		'title'       => __('Home Page Contact Section', 'factory-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','factory-lite'),
		'priority'    => null,
		'panel'       => 'factory_lite_panel_id',
	));

	$wp_customize->add_setting('factory_lite_home_page_contact_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_home_page_contact_text',array(
		'description' => __('<p>1. More options for home page contact section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for home page contact section.</p>','factory-lite'),
		'section'=> 'factory_lite_home_page_contact',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('factory_lite_home_page_contact_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_home_page_contact_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=factory_lite_guide') ." '>More Info</a>",
		'section'=> 'factory_lite_home_page_contact',
		'type'=> 'hidden'
	));

	//Records Section
	$wp_customize->add_section('factory_lite_records', array(
		'title'       => __('Records Section', 'factory-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','factory-lite'),
		'priority'    => null,
		'panel'       => 'factory_lite_panel_id',
	));

	$wp_customize->add_setting('factory_lite_records_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_records_text',array(
		'description' => __('<p>1. More options for records section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for records section.</p>','factory-lite'),
		'section'=> 'factory_lite_records',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('factory_lite_records_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_records_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=factory_lite_guide') ." '>More Info</a>",
		'section'=> 'factory_lite_records',
		'type'=> 'hidden'
	));

	//Testimonials Section
	$wp_customize->add_section('factory_lite_testimonials', array(
		'title'       => __('Testimonials Section', 'factory-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','factory-lite'),
		'priority'    => null,
		'panel'       => 'factory_lite_panel_id',
	));

	$wp_customize->add_setting('factory_lite_testimonials_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_testimonials_text',array(
		'description' => __('<p>1. More options for testimonials section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for testimonials section.</p>','factory-lite'),
		'section'=> 'factory_lite_testimonials',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('factory_lite_testimonials_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_testimonials_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=factory_lite_guide') ." '>More Info</a>",
		'section'=> 'factory_lite_testimonials',
		'type'=> 'hidden'
	));

	//Faq Section
	$wp_customize->add_section('factory_lite_faq', array(
		'title'       => __('Faq Section', 'factory-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','factory-lite'),
		'priority'    => null,
		'panel'       => 'factory_lite_panel_id',
	));

	$wp_customize->add_setting('factory_lite_faq_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_faq_text',array(
		'description' => __('<p>1. More options for faq section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for faq section.</p>','factory-lite'),
		'section'=> 'factory_lite_faq',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('factory_lite_faq_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_faq_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=factory_lite_guide') ." '>More Info</a>",
		'section'=> 'factory_lite_faq',
		'type'=> 'hidden'
	));

	//Get In Touch Section
	$wp_customize->add_section('factory_lite_get_in_touch', array(
		'title'       => __('Get In Touch Section', 'factory-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','factory-lite'),
		'priority'    => null,
		'panel'       => 'factory_lite_panel_id',
	));

	$wp_customize->add_setting('factory_lite_get_in_touch_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_get_in_touch_text',array(
		'description' => __('<p>1. More options for get in touch section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for get in touch section.</p>','factory-lite'),
		'section'=> 'factory_lite_get_in_touch',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('factory_lite_get_in_touch_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_get_in_touch_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=factory_lite_guide') ." '>More Info</a>",
		'section'=> 'factory_lite_get_in_touch',
		'type'=> 'hidden'
	));

	//Partners Section
	$wp_customize->add_section('factory_lite_partners', array(
		'title'       => __('Partners Section', 'factory-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','factory-lite'),
		'priority'    => null,
		'panel'       => 'factory_lite_panel_id',
	));

	$wp_customize->add_setting('factory_lite_partners_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_partners_text',array(
		'description' => __('<p>1. More options for partners section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for partners section.</p>','factory-lite'),
		'section'=> 'factory_lite_partners',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('factory_lite_partners_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_partners_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=factory_lite_guide') ." '>More Info</a>",
		'section'=> 'factory_lite_partners',
		'type'=> 'hidden'
	));

	//Best Seller Section
	$wp_customize->add_section('factory_lite_best_seller', array(
		'title'       => __('Best Seller Section', 'factory-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','factory-lite'),
		'priority'    => null,
		'panel'       => 'factory_lite_panel_id',
	));

	$wp_customize->add_setting('factory_lite_best_seller_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_best_seller_text',array(
		'description' => __('<p>1. More options for best seller section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for best seller section.</p>','factory-lite'),
		'section'=> 'factory_lite_best_seller',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('factory_lite_best_seller_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_best_seller_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=factory_lite_guide') ." '>More Info</a>",
		'section'=> 'factory_lite_best_seller',
		'type'=> 'hidden'
	));

	//Blogs Section
	$wp_customize->add_section('factory_lite_blogs', array(
		'title'       => __('Blogs Section', 'factory-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','factory-lite'),
		'priority'    => null,
		'panel'       => 'factory_lite_panel_id',
	));

	$wp_customize->add_setting('factory_lite_blogs_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_blogs_text',array(
		'description' => __('<p>1. More options for blogs section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for blogs section.</p>','factory-lite'),
		'section'=> 'factory_lite_blogs',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('factory_lite_blogs_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_blogs_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=factory_lite_guide') ." '>More Info</a>",
		'section'=> 'factory_lite_blogs',
		'type'=> 'hidden'
	));

	//Footer Text
	$wp_customize->add_section('factory_lite_footer',array(
		'title'	=> esc_html__('Footer Settings','factory-lite'),
		'description' => __('For more options of footer section <br/><a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/factory-wordpress-theme/">GET PRO</a>','factory-lite'),
		'panel' => 'factory_lite_panel_id',
	));

	$wp_customize->add_setting( 'factory_lite_footer_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'factory_lite_switch_sanitization'
    ));
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_footer_hide_show',array(
      'label' => esc_html__( 'Show / Hide Footer','factory-lite' ),
      'section' => 'factory_lite_footer'
    )));

   	// font size
	$wp_customize->add_setting('factory_lite_button_footer_font_size',array(
		'default'=> 30,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_button_footer_font_size',array(
		'label'	=> __('Footer Heading Font Size','factory-lite'),
  		'type'        => 'number',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'factory_lite_footer',
	));

	$wp_customize->add_setting('factory_lite_button_footer_heading_letter_spacing',array(
		'default'=> 1,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_button_footer_heading_letter_spacing',array(
		'label'	=> __('Heading Letter Spacing','factory-lite'),
  		'type'        => 'number',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
	),
		'section'=> 'factory_lite_footer',
	));

	// text trasform
	$wp_customize->add_setting('factory_lite_button_footer_text_transform',array(
		'default'=> 'Capitalize',
		'sanitize_callback'	=> 'factory_lite_sanitize_choices'
	));
	$wp_customize->add_control('factory_lite_button_footer_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Heading Text Transform','factory-lite'),
		'choices' => array(
      'Uppercase' => __('Uppercase','factory-lite'),
      'Capitalize' => __('Capitalize','factory-lite'),
      'Lowercase' => __('Lowercase','factory-lite'),
    ),
		'section'=> 'factory_lite_footer',
	));

	$wp_customize->add_setting('factory_lite_footer_heading_weight',array(
        'default' => 600,
        'transport' => 'refresh',
        'sanitize_callback' => 'factory_lite_sanitize_choices'
	));
	$wp_customize->add_control('factory_lite_footer_heading_weight',array(
        'type' => 'select',
        'label' => __('Heading Font Weight','factory-lite'),
        'section' => 'factory_lite_footer',
        'choices' => array(
        	'100' => __('100','factory-lite'),
            '200' => __('200','factory-lite'),
            '300' => __('300','factory-lite'),
            '400' => __('400','factory-lite'),
            '500' => __('500','factory-lite'),
            '600' => __('600','factory-lite'),
            '700' => __('700','factory-lite'),
            '800' => __('800','factory-lite'),
            '900' => __('900','factory-lite'),
        ),
	) );

  	$wp_customize->add_setting('factory_lite_footer_template',array(
	    'default'	=> esc_html('factory_lite-footer-one'),
	    'sanitize_callback'	=> 'factory_lite_sanitize_choices'
  	));
 	$wp_customize->add_control('factory_lite_footer_template',array(
        'label'	=> esc_html__('Footer style','factory-lite'),
        'section'	=> 'factory_lite_footer',
        'setting'	=> 'factory_lite_footer_template',
        'type' => 'select',
        'choices' => array(
            'factory_lite-footer-one' => esc_html__('Style 1', 'factory-lite'),
            'factory_lite-footer-two' => esc_html__('Style 2', 'factory-lite'),
            'factory_lite-footer-three' => esc_html__('Style 3', 'factory-lite'),
            'factory_lite-footer-four' => esc_html__('Style 4', 'factory-lite'),
            'factory_lite-footer-five' => esc_html__('Style 5', 'factory-lite'),
        )
  	));

	$wp_customize->add_setting('factory_lite_footer_background_color', array(
		'default'           => '#202028',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'factory_lite_footer_background_color', array(
		'label'    => __('Footer Background Color', 'factory-lite'),
		'section'  => 'factory_lite_footer',
	)));

	$wp_customize->add_setting('factory_lite_footer_background_image',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'factory_lite_footer_background_image',array(
        'label' => __('Footer Background Image','factory-lite'),
        'section' => 'factory_lite_footer'
	)));

	$wp_customize->add_setting('factory_lite_footer_img_position',array(
	  'default' => 'center center',
	  'transport' => 'refresh',
	  'sanitize_callback' => 'factory_lite_sanitize_choices'
	));
	$wp_customize->add_control('factory_lite_footer_img_position',array(
		'type' => 'select',
		'label' => __('Footer Image Position','factory-lite'),
		'section' => 'factory_lite_footer',
		'choices' 	=> array(
			'left top' 		=> esc_html__( 'Top Left', 'factory-lite' ),
			'center top'   => esc_html__( 'Top', 'factory-lite' ),
			'right top'   => esc_html__( 'Top Right', 'factory-lite' ),
			'left center'   => esc_html__( 'Left', 'factory-lite' ),
			'center center'   => esc_html__( 'Center', 'factory-lite' ),
			'right center'   => esc_html__( 'Right', 'factory-lite' ),
			'left bottom'   => esc_html__( 'Bottom Left', 'factory-lite' ),
			'center bottom'   => esc_html__( 'Bottom', 'factory-lite' ),
			'right bottom'   => esc_html__( 'Bottom Right', 'factory-lite' ),
		),
	));

	// Footer
	$wp_customize->add_setting('factory_lite_img_footer',array(
		'default'=> 'scroll',
		'sanitize_callback'	=> 'factory_lite_sanitize_choices'
	));
	$wp_customize->add_control('factory_lite_img_footer',array(
		'type' => 'select',
		'label'	=> __('Footer Background Attatchment','factory-lite'),
		'choices' => array(
            'fixed' => __('fixed','factory-lite'),
            'scroll' => __('scroll','factory-lite'),
        ),
		'section'=> 'factory_lite_footer',
	));

	$wp_customize->add_setting('factory_lite_footer_widgets_heading',array(
        'default' => 'Left',
        'transport' => 'refresh',
        'sanitize_callback' => 'factory_lite_sanitize_choices'
	));
	$wp_customize->add_control('factory_lite_footer_widgets_heading',array(
        'type' => 'select',
        'label' => __('Footer Widget Heading','factory-lite'),
        'section' => 'factory_lite_footer',
        'choices' => array(
        	'Left' => __('Left','factory-lite'),
            'Center' => __('Center','factory-lite'),
            'Right' => __('Right','factory-lite')
        ),
	) );

	$wp_customize->add_setting('factory_lite_footer_widgets_content',array(
        'default' => 'Left',
        'transport' => 'refresh',
        'sanitize_callback' => 'factory_lite_sanitize_choices'
	));
	$wp_customize->add_control('factory_lite_footer_widgets_content',array(
        'type' => 'select',
        'label' => __('Footer Widget Content','factory-lite'),
        'section' => 'factory_lite_footer',
        'choices' => array(
        	'Left' => __('Left','factory-lite'),
            'Center' => __('Center','factory-lite'),
            'Right' => __('Right','factory-lite')
        ),
	) );

	// footer padding
	$wp_customize->add_setting('factory_lite_footer_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_footer_padding',array(
		'label'	=> __('Footer Top Bottom Padding','factory-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','factory-lite'),
		'input_attrs' => array(
      'placeholder' => __( '10px', 'factory-lite' ),
    ),
		'section'=> 'factory_lite_footer',
		'type'=> 'text'
	));

    // footer social icon
  	$wp_customize->add_setting( 'factory_lite_footer_icon',array(
		'default' => false,
		'transport' => 'refresh',
		'sanitize_callback' => 'factory_lite_switch_sanitization'
    ) );
  	$wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_footer_icon',array(
		'label' => esc_html__( 'Show / Hide Footer Social Icon','factory-lite' ),
		'section' => 'factory_lite_footer'
    )));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('factory_lite_footer_text', array(
		'selector' => '.copyright p',
		'render_callback' => 'factory_lite_Customize_partial_factory_lite_footer_text',
	));

	$wp_customize->add_setting( 'factory_lite_copyright_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'factory_lite_switch_sanitization'
    ));
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_copyright_hide_show',array(
      'label' => esc_html__( 'Show / Hide Copyright','factory-lite' ),
      'section' => 'factory_lite_footer'
    )));

	$wp_customize->add_setting('factory_lite_copyright_background_color', array(
		'default'           => '#ff7109',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'factory_lite_copyright_background_color', array(
		'label'    => __('Copyright Background Color', 'factory-lite'),
		'section'  => 'factory_lite_footer',
	)));

	$wp_customize->add_setting('factory_lite_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_footer_text',array(
		'label'	=> esc_html__('Copyright Text','factory-lite'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Copyright 2020, .....', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('factory_lite_copyright_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_copyright_font_size',array(
		'label'	=> __('Copyright Font Size','factory-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','factory-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('factory_lite_copyright_alingment',array(
        'default' => 'center',
        'sanitize_callback' => 'factory_lite_sanitize_choices'
	));
	$wp_customize->add_control(new factory_lite_Image_Radio_Control($wp_customize, 'factory_lite_copyright_alingment', array(
        'type' => 'select',
        'label' => esc_html__('Copyright Alignment','factory-lite'),
        'section' => 'factory_lite_footer',
        'settings' => 'factory_lite_copyright_alingment',
        'choices' => array(
            'left' => esc_url(get_template_directory_uri()).'/assets/images/copyright1.png',
            'center' => esc_url(get_template_directory_uri()).'/assets/images/copyright2.png',
            'right' => esc_url(get_template_directory_uri()).'/assets/images/copyright3.png'
    ))));

	$wp_customize->add_setting( 'factory_lite_footer_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'factory_lite_switch_sanitization'
    ));
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_footer_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll to Top','factory-lite' ),
      	'section' => 'factory_lite_footer'
    )));

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial('factory_lite_scroll_to_top_icon', array(
		'selector' => '.scrollup i',
		'render_callback' => 'factory_lite_Customize_partial_factory_lite_scroll_to_top_icon',
	));

    $wp_customize->add_setting('factory_lite_scroll_to_top_icon',array(
		'default'	=> 'fas fa-long-arrow-alt-up',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new factory_lite_Toggle_Fontawesome_Icon_Chooser(
        $wp_customize,'factory_lite_scroll_to_top_icon',array(
		'label'	=> __('Add Scroll to Top Icon','factory-lite'),
		'transport' => 'refresh',
		'section'	=> 'factory_lite_footer',
		'setting'	=> 'factory_lite_scroll_to_top_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('factory_lite_scroll_to_top_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_scroll_to_top_font_size',array(
		'label'	=> __('Icon Font Size','factory-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','factory-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('factory_lite_scroll_to_top_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_scroll_to_top_padding',array(
		'label'	=> __('Icon Top Bottom Padding','factory-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','factory-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('factory_lite_scroll_to_top_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_scroll_to_top_width',array(
		'label'	=> __('Icon Width','factory-lite'),
		'description'	=> __('Enter a value in pixels Example:20px','factory-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('factory_lite_scroll_to_top_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_scroll_to_top_height',array(
		'label'	=> __('Icon Height','factory-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','factory-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'factory_lite_scroll_to_top_border_radius', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'factory_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'factory_lite_scroll_to_top_border_radius', array(
		'label'       => esc_html__( 'Icon Border Radius','factory-lite' ),
		'section'     => 'factory_lite_footer',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

    $wp_customize->add_setting('factory_lite_scroll_top_alignment',array(
        'default' => 'Right',
        'sanitize_callback' => 'factory_lite_sanitize_choices'
	));
	$wp_customize->add_control(new factory_lite_Image_Radio_Control($wp_customize, 'factory_lite_scroll_top_alignment', array(
        'type' => 'select',
        'label' => esc_html__('Scroll To Top','factory-lite'),
        'section' => 'factory_lite_footer',
        'settings' => 'factory_lite_scroll_top_alignment',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/layout2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/layout3.png'
    ))));

	//Blog Post
	$wp_customize->add_panel( $factory_lite_parent_panel );

	$BlogPostParentPanel = new factory_lite_WP_Customize_Panel( $wp_customize, 'factory_lite_blog_post_parent_panel', array(
		'title' => esc_html__( 'Blog Post Settings', 'factory-lite' ),
		'panel' => 'factory_lite_panel_id',
		'priority' => 20,
	));

	$wp_customize->add_panel( $BlogPostParentPanel );

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'factory_lite_post_settings', array(
		'title' => esc_html__( 'Post Settings', 'factory-lite' ),
		'panel' => 'factory_lite_blog_post_parent_panel',
	));

	//Blog layout
    $wp_customize->add_setting('factory_lite_blog_layout_option',array(
        'default' => 'Default',
        'sanitize_callback' => 'factory_lite_sanitize_choices'
    ));
    $wp_customize->add_control(new factory_lite_Image_Radio_Control($wp_customize, 'factory_lite_blog_layout_option', array(
        'type' => 'select',
        'label' => esc_html__('Blog Layouts','factory-lite'),
        'section' => 'factory_lite_post_settings',
        'choices' => array(
            'Default' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout2.png',
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout3.png',
    ))));

   	$wp_customize->add_setting('factory_lite_theme_options',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'factory_lite_sanitize_choices'
	));
	$wp_customize->add_control('factory_lite_theme_options',array(
        'type' => 'select',
        'label' => esc_html__('Post Sidebar Layout','factory-lite'),
        'description' => esc_html__('Here you can change the sidebar layout for posts. ','factory-lite'),
        'section' => 'factory_lite_post_settings',
        'choices' => array(
            'Left Sidebar' => esc_html__('Left Sidebar','factory-lite'),
            'Right Sidebar' => esc_html__('Right Sidebar','factory-lite'),
            'One Column' => esc_html__('One Column','factory-lite'),
			'Three Columns' => __('Three Columns','factory-lite'),
			'Four Columns' => __('Four Columns','factory-lite'),
            'Grid Layout' => esc_html__('Grid Layout','factory-lite')
        ),
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('factory_lite_toggle_postdate', array(
		'selector' => '.post-main-box h2 a',
		'render_callback' => 'factory_lite_Customize_partial_factory_lite_toggle_postdate',
	));

	$wp_customize->add_setting( 'factory_lite_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'factory_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_toggle_postdate',array(
        'label' => esc_html__( 'Show / Hide Post Date','factory-lite' ),
        'section' => 'factory_lite_post_settings'
    )));

    $wp_customize->add_setting('factory_lite_toggle_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new factory_lite_Toggle_Fontawesome_Icon_Chooser(
        $wp_customize,'factory_lite_toggle_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','factory-lite'),
		'transport' => 'refresh',
		'section'	=> 'factory_lite_post_settings',
		'setting'	=> 'factory_lite_toggle_postdate_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'factory_lite_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'factory_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_toggle_author',array(
		'label' => esc_html__( 'Show / Hide Author','factory-lite' ),
		'section' => 'factory_lite_post_settings'
    )));

    $wp_customize->add_setting('factory_lite_toggle_author_icon',array(
		'default'	=> 'fas fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new factory_lite_Toggle_Fontawesome_Icon_Chooser(
        $wp_customize,'factory_lite_toggle_author_icon',array(
		'label'	=> __('Add Author Icon','factory-lite'),
		'transport' => 'refresh',
		'section'	=> 'factory_lite_post_settings',
		'setting'	=> 'factory_lite_toggle_author_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'factory_lite_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'factory_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_toggle_comments',array(
		'label' => esc_html__( 'Show / Hide Comments','factory-lite' ),
		'section' => 'factory_lite_post_settings'
    )));

    $wp_customize->add_setting('factory_lite_toggle_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new factory_lite_Toggle_Fontawesome_Icon_Chooser(
        $wp_customize,'factory_lite_toggle_comments_icon',array(
		'label'	=> __('Add Comments Icon','factory-lite'),
		'transport' => 'refresh',
		'section'	=> 'factory_lite_post_settings',
		'setting'	=> 'factory_lite_toggle_comments_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'factory_lite_toggle_time',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'factory_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_toggle_time',array(
		'label' => esc_html__( 'Show / Hide Time','factory-lite' ),
		'section' => 'factory_lite_post_settings'
    )));

    $wp_customize->add_setting('factory_lite_toggle_time_icon',array(
		'default'	=> 'fas fa-clock',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new factory_lite_Toggle_Fontawesome_Icon_Chooser(
        $wp_customize,'factory_lite_toggle_time_icon',array(
		'label'	=> __('Add Time Icon','factory-lite'),
		'transport' => 'refresh',
		'section'	=> 'factory_lite_post_settings',
		'setting'	=> 'factory_lite_toggle_time_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'factory_lite_featured_image_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'factory_lite_switch_sanitization'
	));
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_featured_image_hide_show', array(
		'label' => esc_html__( 'Show / Hide Featured Image','factory-lite' ),
		'section' => 'factory_lite_post_settings'
    )));

    $wp_customize->add_setting( 'factory_lite_featured_image_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'factory_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'factory_lite_featured_image_border_radius', array(
		'label'       => esc_html__( 'Featured Image Border Radius','factory-lite' ),
		'section'     => 'factory_lite_post_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'factory_lite_featured_image_box_shadow', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'factory_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'factory_lite_featured_image_box_shadow', array(
		'label'       => esc_html__( 'Featured Image Box Shadow','factory-lite' ),
		'section'     => 'factory_lite_post_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Featured Image
	$wp_customize->add_setting('factory_lite_blog_post_featured_image_dimension',array(
       'default' => 'default',
       'sanitize_callback'	=> 'factory_lite_sanitize_choices'
	));
  	$wp_customize->add_control('factory_lite_blog_post_featured_image_dimension',array(
		'type' => 'select',
		'label'	=> __('Blog Post Featured Image Dimension','factory-lite'),
		'section'	=> 'factory_lite_post_settings',
		'choices' => array(
			'default' => __('Default','factory-lite'),
			'custom' => __('Custom Image Size','factory-lite'),
      ),
  	));

	$wp_customize->add_setting('factory_lite_blog_post_featured_image_custom_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_blog_post_featured_image_custom_width',array(
		'label'	=> __('Featured Image Custom Width','factory-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','factory-lite'),
		'input_attrs' => array(
    	'placeholder' => __( '10px', 'factory-lite' ),),
		'section'=> 'factory_lite_post_settings',
		'type'=> 'text',
		'active_callback' => 'factory_lite_blog_post_featured_image_dimension'
	));

	$wp_customize->add_setting('factory_lite_blog_post_featured_image_custom_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_blog_post_featured_image_custom_height',array(
		'label'	=> __('Featured Image Custom Height','factory-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','factory-lite'),
		'input_attrs' => array(
    	'placeholder' => __( '10px', 'factory-lite' ),),
		'section'=> 'factory_lite_post_settings',
		'type'=> 'text',
		'active_callback' => 'factory_lite_blog_post_featured_image_dimension'
	));

    $wp_customize->add_setting( 'factory_lite_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'factory_lite_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'factory_lite_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','factory-lite' ),
		'section'     => 'factory_lite_post_settings',
		'type'        => 'range',
		'settings'    => 'factory_lite_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('factory_lite_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','factory-lite'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','factory-lite'),
		'section'=> 'factory_lite_post_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('factory_lite_blog_page_posts_settings',array(
        'default' => 'Into Blocks',
        'transport' => 'refresh',
        'sanitize_callback' => 'factory_lite_sanitize_choices'
	));
	$wp_customize->add_control('factory_lite_blog_page_posts_settings',array(
        'type' => 'select',
        'label' => __('Display Blog Posts','factory-lite'),
        'section' => 'factory_lite_post_settings',
        'choices' => array(
        	'Into Blocks' => __('Into Blocks','factory-lite'),
            'Without Blocks' => __('Without Blocks','factory-lite')
        ),
	) );

    $wp_customize->add_setting('factory_lite_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'factory_lite_sanitize_choices'
	));
	$wp_customize->add_control('factory_lite_excerpt_settings',array(
        'type' => 'select',
        'label' => esc_html__('Post Content','factory-lite'),
        'section' => 'factory_lite_post_settings',
        'choices' => array(
        	'Content' => esc_html__('Content','factory-lite'),
            'Excerpt' => esc_html__('Excerpt','factory-lite'),
            'No Content' => esc_html__('No Content','factory-lite')
        ),
	) );

	$wp_customize->add_setting('factory_lite_blog_excerpt_suffix',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_blog_excerpt_suffix',array(
		'label'	=> __('Add Excerpt Suffix','factory-lite'),
		'input_attrs' => array(
            'placeholder' => __( '[...]', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_post_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'factory_lite_blog_pagination_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'factory_lite_switch_sanitization'
    ));
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_blog_pagination_hide_show',array(
		'label' => esc_html__( 'Show / Hide Blog Pagination','factory-lite' ),
		'section' => 'factory_lite_post_settings'
    )));

	$wp_customize->add_setting( 'factory_lite_blog_pagination_type', array(
        'default'			=> 'blog-page-numbers',
        'sanitize_callback'	=> 'factory_lite_sanitize_choices'
    ));
    $wp_customize->add_control( 'factory_lite_blog_pagination_type', array(
        'section' => 'factory_lite_post_settings',
        'type' => 'select',
        'label' => __( 'Blog Pagination', 'factory-lite' ),
        'choices'		=> array(
            'blog-page-numbers'  => __( 'Numeric', 'factory-lite' ),
            'next-prev' => __( 'Older Posts/Newer Posts', 'factory-lite' ),
    )));

    // Button Settings
	$wp_customize->add_section( 'factory_lite_button_settings', array(
		'title' => esc_html__( 'Button Settings', 'factory-lite' ),
		'panel' => 'factory_lite_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('factory_lite_button_text', array(
		'selector' => '.post-main-box .more-btn a',
		'render_callback' => 'factory_lite_Customize_partial_factory_lite_button_text',
	));

    $wp_customize->add_setting('factory_lite_button_text',array(
		'default'=> esc_html__('Read More','factory-lite'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_button_text',array(
		'label'	=> esc_html__('Add Button Text','factory-lite'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Read More', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_button_settings',
		'type'=> 'text'
	));

	// font size button
	$wp_customize->add_setting('factory_lite_button_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_button_font_size',array(
		'label'	=> __('Button Font Size','factory-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','factory-lite'),
		'input_attrs' => array(
     	'placeholder' => __( '10px', 'factory-lite' ),
    ),
    	'type'        => 'text',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'factory_lite_button_settings',
	));

	$wp_customize->add_setting( 'factory_lite_button_border_radius', array(
		'default'              => 5,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'factory_lite_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'factory_lite_button_border_radius', array(
		'label'       => esc_html__( 'Button Border Radius','factory-lite' ),
		'section'     => 'factory_lite_button_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('factory_lite_button_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_button_padding_top_bottom',array(
		'label'	=> esc_html__('Padding Top Bottom','factory-lite'),
		'description' => esc_html__('Enter a value in pixels. Example:20px','factory-lite'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '10px', 'factory-lite' ),
        ),
		'section' => 'factory_lite_button_settings',
		'type' => 'text'
	));

	$wp_customize->add_setting('factory_lite_button_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_button_padding_left_right',array(
		'label'	=> esc_html__('Padding Left Right','factory-lite'),
		'description' => esc_html__('Enter a value in pixels. Example:20px','factory-lite'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '10px', 'factory-lite' ),
        ),
		'section' => 'factory_lite_button_settings',
		'type' => 'text'
	));

	$wp_customize->add_setting('factory_lite_button_letter_spacing',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_button_letter_spacing',array(
		'label'	=> __('Button Letter Spacing','factory-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','factory-lite'),
		'input_attrs' => array(
      	'placeholder' => __( '10px', 'factory-lite' ),
    ),
    	'type'        => 'text',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'factory_lite_button_settings',
	));

	// text trasform
	$wp_customize->add_setting('factory_lite_button_text_transform',array(
		'default'=> 'Uppercase',
		'sanitize_callback'	=> 'factory_lite_sanitize_choices'
	));
	$wp_customize->add_control('factory_lite_button_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Button Text Transform','factory-lite'),
		'choices' => array(
            'Uppercase' => __('Uppercase','factory-lite'),
            'Capitalize' => __('Capitalize','factory-lite'),
            'Lowercase' => __('Lowercase','factory-lite'),
        ),
		'section'=> 'factory_lite_button_settings',
	));

	// Related Post Settings
	$wp_customize->add_section( 'factory_lite_related_posts_settings', array(
		'title' => esc_html__( 'Related Posts Settings', 'factory-lite' ),
		'panel' => 'factory_lite_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('factory_lite_related_post_title', array(
		'selector' => '.related-post h3',
		'render_callback' => 'factory_lite_Customize_partial_factory_lite_related_post_title',
	));

    $wp_customize->add_setting( 'factory_lite_related_post',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'factory_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_related_post',array(
		'label' => esc_html__( 'Show / Hide Related Post','factory-lite' ),
		'section' => 'factory_lite_related_posts_settings'
    )));

    $wp_customize->add_setting('factory_lite_related_post_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_related_post_title',array(
		'label'	=> esc_html__('Add Related Post Title','factory-lite'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Related Post', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_related_posts_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('factory_lite_related_posts_count',array(
		'default'=> 3,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_related_posts_count',array(
		'label'	=> esc_html__('Add Related Post Count','factory-lite'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '3', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_related_posts_settings',
		'type'=> 'number'
	));

	$wp_customize->add_setting( 'factory_lite_related_posts_excerpt_number', array(
		'default'              => 20,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'factory_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'factory_lite_related_posts_excerpt_number', array(
		'label'       => esc_html__( 'Related Posts Excerpt length','factory-lite' ),
		'section'     => 'factory_lite_related_posts_settings',
		'type'        => 'range',
		'settings'    => 'factory_lite_related_posts_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	// Single Posts Settings
	$wp_customize->add_section( 'factory_lite_single_blog_settings', array(
		'title' => __( 'Single Post Settings', 'factory-lite' ),
		'panel' => 'factory_lite_blog_post_parent_panel',
	));

  	$wp_customize->add_setting('factory_lite_single_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new factory_lite_Toggle_Fontawesome_Icon_Chooser(
        $wp_customize,'factory_lite_single_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','factory-lite'),
		'transport' => 'refresh',
		'section'	=> 'factory_lite_single_blog_settings',
		'setting'	=> 'factory_lite_single_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'factory_lite_single_postdate',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'factory_lite_switch_sanitization'
	) );
	$wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_single_postdate',array(
	    'label' => esc_html__( 'Show / Hide Date','factory-lite' ),
	   'section' => 'factory_lite_single_blog_settings'
	)));

	$wp_customize->add_setting('factory_lite_single_author_icon',array(
		'default'	=> 'fas fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new factory_lite_Toggle_Fontawesome_Icon_Chooser(
        $wp_customize,'factory_lite_single_author_icon',array(
		'label'	=> __('Add Author Icon','factory-lite'),
		'transport' => 'refresh',
		'section'	=> 'factory_lite_single_blog_settings',
		'setting'	=> 'factory_lite_single_author_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'factory_lite_single_author',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'factory_lite_switch_sanitization'
	) );
	$wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_single_author',array(
	    'label' => esc_html__( 'Show / Hide Author','factory-lite' ),
	    'section' => 'factory_lite_single_blog_settings'
	)));

   	$wp_customize->add_setting('factory_lite_single_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new factory_lite_Toggle_Fontawesome_Icon_Chooser(
        $wp_customize,'factory_lite_single_comments_icon',array(
		'label'	=> __('Add Comments Icon','factory-lite'),
		'transport' => 'refresh',
		'section'	=> 'factory_lite_single_blog_settings',
		'setting'	=> 'factory_lite_single_comments_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'factory_lite_single_comments',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'factory_lite_switch_sanitization'
	) );
	$wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_single_comments',array(
	    'label' => esc_html__( 'Show / Hide Comments','factory-lite' ),
	    'section' => 'factory_lite_single_blog_settings'
	)));

  	$wp_customize->add_setting('factory_lite_single_time_icon',array(
		'default'	=> 'fas fa-clock',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new factory_lite_Toggle_Fontawesome_Icon_Chooser(
        $wp_customize,'factory_lite_single_time_icon',array(
		'label'	=> __('Add Time Icon','factory-lite'),
		'transport' => 'refresh',
		'section'	=> 'factory_lite_single_blog_settings',
		'setting'	=> 'factory_lite_single_time_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'factory_lite_single_time',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'factory_lite_switch_sanitization'
	) );

	$wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_single_time',array(
	    'label' => esc_html__( 'Show / Hide Time','factory-lite' ),
	    'section' => 'factory_lite_single_blog_settings'
	)));

	$wp_customize->add_setting( 'factory_lite_single_post_breadcrumb',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'factory_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_single_post_breadcrumb',array(
		'label' => esc_html__( 'Show / Hide Breadcrumb','factory-lite' ),
		'section' => 'factory_lite_single_blog_settings'
    )));

    // Single Posts Category
  	$wp_customize->add_setting( 'factory_lite_single_post_category',array(
		'default' => true,
		'transport' => 'refresh',
		'sanitize_callback' => 'factory_lite_switch_sanitization'
    ) );
  	$wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_single_post_category',array(
		'label' => esc_html__( 'Show / Hide Category','factory-lite' ),
		'section' => 'factory_lite_single_blog_settings'
    )));

	$wp_customize->add_setting( 'factory_lite_toggle_tags',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'factory_lite_switch_sanitization'
	));
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_toggle_tags', array(
		'label' => esc_html__( 'Show / Hide Tags','factory-lite' ),
		'section' => 'factory_lite_single_blog_settings'
    )));

	$wp_customize->add_setting( 'factory_lite_single_blog_post_navigation_show_hide',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'factory_lite_switch_sanitization'
	));
	$wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_single_blog_post_navigation_show_hide', array(
		  'label' => esc_html__( 'Show / Hide Post Navigation','factory-lite' ),
		  'section' => 'factory_lite_single_blog_settings'
	)));

	//navigation text
	$wp_customize->add_setting('factory_lite_single_blog_prev_navigation_text',array(
		'default'=> 'PREVIOUS',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_single_blog_prev_navigation_text',array(
		'label'	=> __('Post Navigation Text','factory-lite'),
		'input_attrs' => array(
    'placeholder' => __( 'PREVIOUS', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_single_blog_settings',
		'type'=> 'text'
	)); 

	$wp_customize->add_setting('factory_lite_single_blog_next_navigation_text',array(
		'default'=> 'NEXT',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_single_blog_next_navigation_text',array(
		'label'	=> __('Post Navigation Text','factory-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'NEXT', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('factory_lite_single_post_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_single_post_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','factory-lite'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','factory-lite'),
		'section'=> 'factory_lite_single_blog_settings',
		'type'=> 'text'
	));

    $wp_customize->add_setting('factory_lite_single_blog_comment_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('factory_lite_single_blog_comment_title',array(
		'label'	=> __('Add Comment Title','factory-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Leave a Reply', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('factory_lite_single_blog_comment_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('factory_lite_single_blog_comment_button_text',array(
		'label'	=> __('Add Comment Button Text','factory-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Post Comment', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_single_blog_settings',
		'type'=> 'text'
	));

    $wp_customize->add_setting('factory_lite_single_blog_comment_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_single_blog_comment_width',array(
		'label'	=> __('Comment Form Width','factory-lite'),
		'description'	=> __('Enter a value in %. Example:50%','factory-lite'),
		'input_attrs' => array(
            'placeholder' => __( '100%', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_single_blog_settings',
		'type'=> 'text'
	));

	// Grid layout setting
	$wp_customize->add_section( 'factory_lite_grid_layout_settings', array(
		'title' => __( 'Grid Layout Settings', 'factory-lite' ),
		'panel' => 'factory_lite_blog_post_parent_panel',
	));

  	$wp_customize->add_setting('factory_lite_grid_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new factory_lite_Toggle_Fontawesome_Icon_Chooser(
        $wp_customize,'factory_lite_grid_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','factory-lite'),
		'transport' => 'refresh',
		'section'	=> 'factory_lite_grid_layout_settings',
		'setting'	=> 'factory_lite_grid_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'factory_lite_grid_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'factory_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_grid_postdate',array(
        'label' => esc_html__( 'Show / Hide Post Date','factory-lite' ),
        'section' => 'factory_lite_grid_layout_settings'
    )));

	$wp_customize->add_setting('factory_lite_grid_author_icon',array(
		'default'	=> 'fas fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new factory_lite_Toggle_Fontawesome_Icon_Chooser(
        $wp_customize,'factory_lite_grid_author_icon',array(
		'label'	=> __('Add Author Icon','factory-lite'),
		'transport' => 'refresh',
		'section'	=> 'factory_lite_grid_layout_settings',
		'setting'	=> 'factory_lite_grid_author_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'factory_lite_grid_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'factory_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_grid_author',array(
		'label' => esc_html__( 'Show / Hide Author','factory-lite' ),
		'section' => 'factory_lite_grid_layout_settings'
    )));

   	$wp_customize->add_setting('factory_lite_grid_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new factory_lite_Toggle_Fontawesome_Icon_Chooser(
        $wp_customize,'factory_lite_grid_comments_icon',array(
		'label'	=> __('Add Comments Icon','factory-lite'),
		'transport' => 'refresh',
		'section'	=> 'factory_lite_grid_layout_settings',
		'setting'	=> 'factory_lite_grid_comments_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'factory_lite_grid_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'factory_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_grid_comments',array(
		'label' => esc_html__( 'Show / Hide Comments','factory-lite' ),
		'section' => 'factory_lite_grid_layout_settings'
    )));

  	$wp_customize->add_setting('factory_lite_display_grid_posts_settings',array(
	    'default' => 'Into Blocks',
	    'transport' => 'refresh',
	    'sanitize_callback' => 'factory_lite_sanitize_choices'
	));
	$wp_customize->add_control('factory_lite_display_grid_posts_settings',array(
	    'type' => 'select',
	    'label' => __('Display Grid Posts','factory-lite'),
	    'section' => 'factory_lite_grid_layout_settings',
	    'choices' => array(
	    	'Into Blocks' => __('Into Blocks','factory-lite'),
	      	'Without Blocks' => __('Without Blocks','factory-lite')
      ),
	) );

	$wp_customize->add_setting('factory_lite_grid_button_text',array(
		'default'=> esc_html__('Read More','factory-lite'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_grid_button_text',array(
		'label'	=> esc_html__('Add Button Text','factory-lite'),
		'input_attrs' => array(
        'placeholder' => esc_html__( 'Read More', 'factory-lite' ),
      ),
		'section'=> 'factory_lite_grid_layout_settings',
		'type'=> 'text'
	));

  	$wp_customize->add_setting('factory_lite_grid_button_icon',array(
		'default'	=> 'fas fa-angle-double-right',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new factory_lite_Toggle_Fontawesome_Icon_Chooser(
        $wp_customize,'factory_lite_grid_button_icon',array(
		'label'	=> __('Add Grid Button Icon','factory-lite'),
		'transport' => 'refresh',
		'section'	=> 'factory_lite_grid_layout_settings',
		'setting'	=> 'factory_lite_grid_button_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('factory_lite_grid_excerpt_suffix',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_grid_excerpt_suffix',array(
		'label'	=> __('Add Excerpt Suffix','factory-lite'),
		'input_attrs' => array(
            'placeholder' => __( '[...]', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_grid_layout_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('factory_lite_grid_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'factory_lite_sanitize_choices'
	));
	$wp_customize->add_control('factory_lite_grid_excerpt_settings',array(
        'type' => 'select',
        'label' => esc_html__('Grid Post Content','factory-lite'),
        'section' => 'factory_lite_grid_layout_settings',
        'choices' => array(
        	'Content' => esc_html__('Content','factory-lite'),
            'Excerpt' => esc_html__('Excerpt','factory-lite'),
            'No Content' => esc_html__('No Content','factory-lite')
        ),
	) );

	//Other Settings
	$wp_customize->add_panel( $factory_lite_parent_panel );

	$OtherParentPanel = new factory_lite_WP_Customize_Panel( $wp_customize, 'factory_lite_other_parent_panel', array(
		'title' => esc_html__( 'Other Settings', 'factory-lite' ),
		'panel' => 'factory_lite_panel_id',
		'priority' => 20,
	));

	$wp_customize->add_panel( $OtherParentPanel );

	// Layout
	$wp_customize->add_section( 'factory_lite_left_right', array(
    	'title' => esc_html__( 'General Settings', 'factory-lite' ),
		'panel' => 'factory_lite_other_parent_panel'
	) );

	$wp_customize->add_setting('factory_lite_width_option',array(
        'default' => 'Full Width',
        'sanitize_callback' => 'factory_lite_sanitize_choices'
	));
	$wp_customize->add_control(new factory_lite_Image_Radio_Control($wp_customize, 'factory_lite_width_option', array(
        'type' => 'select',
        'label' => esc_html__('Width Layouts','factory-lite'),
        'description' => esc_html__('Here you can change the width layout of Website.','factory-lite'),
        'section' => 'factory_lite_left_right',
        'choices' => array(
            'Full Width' => esc_url(get_template_directory_uri()).'/assets/images/full-width.png',
            'Wide Width' => esc_url(get_template_directory_uri()).'/assets/images/wide-width.png',
            'Boxed' => esc_url(get_template_directory_uri()).'/assets/images/boxed-width.png',
    ))));

	$wp_customize->add_setting('factory_lite_page_layout',array(
        'default' => 'One_Column',
        'sanitize_callback' => 'factory_lite_sanitize_choices'
	));
	$wp_customize->add_control('factory_lite_page_layout',array(
        'type' => 'select',
        'label' => esc_html__('Page Sidebar Layout','factory-lite'),
        'description' => esc_html__('Here you can change the sidebar layout for pages. ','factory-lite'),
        'section' => 'factory_lite_left_right',
        'choices' => array(
            'Left_Sidebar' => esc_html__('Left Sidebar','factory-lite'),
            'Right_Sidebar' => esc_html__('Right Sidebar','factory-lite'),
            'One_Column' => esc_html__('One Column','factory-lite')
        ),
	) );

    $wp_customize->add_setting( 'factory_lite_single_page_breadcrumb',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'factory_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_single_page_breadcrumb',array(
		'label' => esc_html__( 'Show / Hide Page Breadcrumb','factory-lite' ),
		'section' => 'factory_lite_left_right'
    )));

    //Wow Animation
	$wp_customize->add_setting( 'factory_lite_animation',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'factory_lite_switch_sanitization'
    ));
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_animation',array(
        'label' => esc_html__( 'Show / Hide Animations','factory-lite' ),
        'description' => __('Here you can disable overall site animation effect','factory-lite'),
        'section' => 'factory_lite_left_right'
    )));

    $wp_customize->add_setting('factory_lite_reset_all_settings',array(
      'sanitize_callback'	=> 'sanitize_text_field',
   	));
   	$wp_customize->add_control(new factory_lite_Reset_Custom_Control($wp_customize, 'factory_lite_reset_all_settings',array(
      'type' => 'reset_control',
      'label' => __('Reset All Settings', 'factory-lite'),
      'description' => 'factory_lite_reset_all_settings',
      'section' => 'factory_lite_left_right'
   	)));

    //Pre-Loader
	$wp_customize->add_setting( 'factory_lite_loader_enable',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'factory_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_loader_enable',array(
        'label' => esc_html__( 'Show / Hide Pre-Loader','factory-lite' ),
        'section' => 'factory_lite_left_right'
    )));

	$wp_customize->add_setting('factory_lite_preloader_bg_color', array(
		'default'           => '#ff7109',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'factory_lite_preloader_bg_color', array(
		'label'    => __('Pre-Loader Background Color', 'factory-lite'),
		'section'  => 'factory_lite_left_right',
	)));

	$wp_customize->add_setting('factory_lite_preloader_border_color', array(
		'default'           => '#ffffff',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'factory_lite_preloader_border_color', array(
		'label'    => __('Pre-Loader Border Color', 'factory-lite'),
		'section'  => 'factory_lite_left_right',
	)));

	$wp_customize->add_setting('factory_lite_preloader_bg_img',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'factory_lite_preloader_bg_img',array(
        'label' => __('Preloader Background Image','factory-lite'),
        'section' => 'factory_lite_left_right'
	)));

	$wp_customize->add_setting('factory_lite_preloader_bg_img',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'factory_lite_preloader_bg_img',array(
        'label' => __('Preloader Background Image','factory-lite'),
        'section' => 'factory_lite_left_right'
	)));

	//No Result Page Setting
	$wp_customize->add_section('factory_lite_no_results_page',array(
		'title'	=> __('No Results Page Settings','factory-lite'),
		'panel' => 'factory_lite_other_parent_panel',
	));

	$wp_customize->add_setting('factory_lite_no_results_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('factory_lite_no_results_page_title',array(
		'label'	=> __('Add Title','factory-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Nothing Found', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_no_results_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('factory_lite_no_results_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('factory_lite_no_results_page_content',array(
		'label'	=> __('Add Text','factory-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Sorry, but nothing matched your search terms. Please try again with some different keywords.', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_no_results_page',
		'type'=> 'text'
	));

	//Responsive Media Settings
	$wp_customize->add_section('factory_lite_responsive_media',array(
		'title'	=> esc_html__('Responsive Media','factory-lite'),
		'panel' => 'factory_lite_other_parent_panel',
	));

    $wp_customize->add_setting( 'factory_lite_resp_slider_hide_show',array(
      	'default' => 1,
     	'transport' => 'refresh',
      	'sanitize_callback' => 'factory_lite_switch_sanitization'
    ));
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_resp_slider_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Slider','factory-lite' ),
      	'section' => 'factory_lite_responsive_media'
    )));

    $wp_customize->add_setting( 'factory_lite_sidebar_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'factory_lite_switch_sanitization'
    ));
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_sidebar_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Sidebar','factory-lite' ),
      	'section' => 'factory_lite_responsive_media'
    )));

    $wp_customize->add_setting( 'factory_lite_resp_scroll_top_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'factory_lite_switch_sanitization'
    ));
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_resp_scroll_top_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','factory-lite' ),
      	'section' => 'factory_lite_responsive_media'
    )));

    $wp_customize->add_setting('factory_lite_resp_menu_toggle_btn_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'factory_lite_resp_menu_toggle_btn_bg_color', array(
		'label'    => __('Toggle Button Bg Color', 'factory-lite'),
		'section'  => 'factory_lite_responsive_media',
	)));

    $wp_customize->add_setting('factory_lite_res_open_menu_icon',array(
		'default'	=> 'fas fa-bars',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new factory_lite_Toggle_Fontawesome_Icon_Chooser(
        $wp_customize,'factory_lite_res_open_menu_icon',array(
		'label'	=> __('Add Open Menu Icon','factory-lite'),
		'transport' => 'refresh',
		'section'	=> 'factory_lite_responsive_media',
		'setting'	=> 'factory_lite_res_open_menu_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('factory_lite_res_close_menu_icon',array(
		'default'	=> 'fas fa-times',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new factory_lite_Toggle_Fontawesome_Icon_Chooser(
        $wp_customize,'factory_lite_res_close_menu_icon',array(
		'label'	=> __('Add Close Menu Icon','factory-lite'),
		'transport' => 'refresh',
		'section'	=> 'factory_lite_responsive_media',
		'setting'	=> 'factory_lite_res_close_menu_icon',
		'type'		=> 'icon'
	)));


    //Woocommerce settings
	$wp_customize->add_section('factory_lite_woocommerce_section', array(
		'title'    => __('WooCommerce Layout', 'factory-lite'),
		'priority' => null,
		'panel'    => 'woocommerce',
	));

    //Shop Page Featured Image
	$wp_customize->add_setting( 'factory_lite_shop_featured_image_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'factory_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'factory_lite_shop_featured_image_border_radius', array(
		'label'       => esc_html__( 'Shop Page Featured Image Border Radius','factory-lite' ),
		'section'     => 'factory_lite_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'factory_lite_shop_featured_image_box_shadow', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'factory_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'factory_lite_shop_featured_image_box_shadow', array(
		'label'       => esc_html__( 'Shop Page Featured Image Box Shadow','factory-lite' ),
		'section'     => 'factory_lite_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'factory_lite_woocommerce_shop_page_sidebar', array( 'selector' => '.post-type-archive-product #sidebar',
		'render_callback' => 'factory_lite_customize_partial_factory_lite_woocommerce_shop_page_sidebar', ) );

    //Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'factory_lite_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'factory_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Show / Hide Shop Page Sidebar','factory-lite' ),
		'section' => 'factory_lite_woocommerce_section'
    )));

    $wp_customize->add_setting('factory_lite_shop_page_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'factory_lite_sanitize_choices'
	));
	$wp_customize->add_control('factory_lite_shop_page_layout',array(
        'type' => 'select',
        'label' => __('Shop Page Sidebar Layout','factory-lite'),
        'section' => 'factory_lite_woocommerce_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','factory-lite'),
            'Right Sidebar' => __('Right Sidebar','factory-lite'),
        ),
	) );

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'factory_lite_woocommerce_single_product_page_sidebar', array( 'selector' => '.single-product #sidebar',
		'render_callback' => 'factory_lite_customize_partial_factory_lite_woocommerce_single_product_page_sidebar', ) );

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'factory_lite_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'factory_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Show / Hide Single Product Sidebar','factory-lite' ),
		'section' => 'factory_lite_woocommerce_section'
    )));

   	$wp_customize->add_setting('factory_lite_single_product_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'factory_lite_sanitize_choices'
	));
	$wp_customize->add_control('factory_lite_single_product_layout',array(
        'type' => 'select',
        'label' => __('Single Product Sidebar Layout','factory-lite'),
        'section' => 'factory_lite_woocommerce_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','factory-lite'),
            'Right Sidebar' => __('Right Sidebar','factory-lite'),
        ),
	) );

	$wp_customize->add_setting('factory_lite_products_btn_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_products_btn_padding_top_bottom',array(
		'label'	=> __('Products Button Padding Top Bottom','factory-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','factory-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('factory_lite_products_btn_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_products_btn_padding_left_right',array(
		'label'	=> __('Products Button Padding Left Right','factory-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','factory-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_woocommerce_section',
		'type'=> 'text'
	));

	//Products Sale Badge
	$wp_customize->add_setting('factory_lite_woocommerce_sale_position',array(
        'default' => 'left',
        'sanitize_callback' => 'factory_lite_sanitize_choices'
	));
	$wp_customize->add_control('factory_lite_woocommerce_sale_position',array(
        'type' => 'select',
        'label' => __('Sale Badge Position','factory-lite'),
        'section' => 'factory_lite_woocommerce_section',
        'choices' => array(
            'left' => __('Left','factory-lite'),
            'right' => __('Right','factory-lite'),
        ),
	) );

	$wp_customize->add_setting('factory_lite_woocommerce_sale_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_woocommerce_sale_padding_top_bottom',array(
		'label'	=> __('Sale Padding Top Bottom','factory-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','factory-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('factory_lite_woocommerce_sale_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('factory_lite_woocommerce_sale_padding_left_right',array(
		'label'	=> __('Sale Padding Left Right','factory-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','factory-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'factory-lite' ),
        ),
		'section'=> 'factory_lite_woocommerce_section',
		'type'=> 'text'
	));

    $wp_customize->add_setting( 'factory_lite_related_product_show_hide',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'factory_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Factory_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'factory_lite_related_product_show_hide',array(
        'label' => esc_html__( 'Show / Hide Related product','factory-lite' ),
        'section' => 'factory_lite_woocommerce_section'
    )));

    // Has to be at the top
	$wp_customize->register_panel_type( 'factory_lite_WP_Customize_Panel' );
	$wp_customize->register_section_type( 'factory_lite_WP_Customize_Section' );
}

add_action( 'customize_register', 'factory_lite_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

if ( class_exists( 'WP_Customize_Panel' ) ) {
  	class factory_lite_WP_Customize_Panel extends WP_Customize_Panel {
	    public $panel;
	    public $type = 'factory_lite_panel';
	    public function json() {
			$array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'type', 'panel', ) );
			$array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
			$array['content'] = $this->get_content();
			$array['active'] = $this->active();
			$array['instanceNumber'] = $this->instance_number;
			return $array;
    	}
  	}
}

if ( class_exists( 'WP_Customize_Section' ) ) {
  	class factory_lite_WP_Customize_Section extends WP_Customize_Section {
	    public $section;
	    public $type = 'factory_lite_section';
	    public function json() {
			$array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'panel', 'type', 'description_hidden', 'section', ) );
			$array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
			$array['content'] = $this->get_content();
			$array['active'] = $this->active();
			$array['instanceNumber'] = $this->instance_number;

			if ( $this->panel ) {
			$array['customizeAction'] = sprintf( 'Customizing &#9656; %s', esc_html( $this->manager->get_panel( $this->panel )->title ) );
			} else {
			$array['customizeAction'] = 'Customizing';
			}
			return $array;
    	}
  	}
}

// Enqueue our scripts and styles
function factory_lite_Customize_controls_scripts() {
	wp_enqueue_script( 'factory-lite-customizer-controls', get_theme_file_uri( '/assets/js/customizer-controls.js' ), array(), '1.0', true );
}
add_action( 'customize_controls_enqueue_scripts', 'factory_lite_Customize_controls_scripts' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class factory_lite_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	*/
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'factory_lite_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section( new factory_lite_Customize_Section_Pro( $manager,'factory_lite_go_pro', array(
			'priority'   => 1,
			'title'    => esc_html__( 'FACTORY PRO', 'factory-lite' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'factory-lite' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/factory-wordpress-theme/'),
		) )	);

		$manager->add_section(new factory_lite_Customize_Section_Pro($manager,'factory_lite_get_started_link',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'factory-lite' ),
			'pro_text' => esc_html__( 'DOCS', 'factory-lite' ),
			'pro_url'  => esc_url('https://preview.vwthemesdemo.com/docs/free-factory-lite/'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'factory-lite-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'factory-lite-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );

		wp_localize_script(
		'factory-lite-customize-controls',
		'factory_lite_customizer_params',
		array(
			'ajaxurl' =>	admin_url( 'admin-ajax.php' )
		));
	}
}

// Doing this customizer thang!
factory_lite_Customize::get_instance();
